summaryrefslogtreecommitdiffstats
path: root/arch
diff options
context:
space:
mode:
Diffstat (limited to 'arch')
-rw-r--r--arch/mips64/kernel/head.S3
1 files changed, 2 insertions, 1 deletions
diff --git a/arch/mips64/kernel/head.S b/arch/mips64/kernel/head.S
index 3e736acf7..85e99faae 100644
--- a/arch/mips64/kernel/head.S
+++ b/arch/mips64/kernel/head.S
@@ -86,7 +86,8 @@ NESTED(mapped_kernel_setup_tlb, 16, sp)
dmtc0 t0, CP0_ENTRYHI
li t0, ((_PAGE_GLOBAL|_PAGE_VALID| _PAGE_DIRTY|_CACHE_CACHABLE_COW) >> 6)
mtc0 t0, CP0_ENTRYLO0 # physaddr 0, DVG, cach exlwr
- mtc0 zero, CP0_ENTRYLO1 # 16M should be enough for text+data
+ li t0, (_PAGE_GLOBAL >> 6) # allow global access to kernel
+ mtc0 t0, CP0_ENTRYLO1 # 16M should be enough for text+data
li t0, 0x1ffe000 # MAPPED_KERN_TLBMASK, TLBPGMASK_16M
mtc0 t0, CP0_PAGEMASK
li t0, 0 # KMAP_INX